@@ -130,5 +130,5 @@ class UDevVersion(Directive):
 
 def setup(app):
     from sphinx.ext.autodoc import cut_lines
-    app.connect(b'autodoc-process-docstring', cut_lines(2, what=['module']))
+    app.connect('autodoc-process-docstring', cut_lines(2, what=['module']))
     app.add_directive('udevversion', UDevVersion)
