@@ -14,8 +14,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this library; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-
-
 """plugins.mock_libudev
     ====================
 
@@ -34,9 +32,9 @@ from operator import attrgetter
 from contextlib import contextmanager
 from collections import namedtuple
 
+import pytest
 import mock
 
-
 Node = namedtuple('Node', 'name value next')
 
 
@@ -79,9 +77,10 @@ def libudev_list(libudev, function, items):
     the second the item value, or a single element, which is the item name.
     The item value is ``None`` in this case.
     """
-    functions_to_patch = [function, 'udev_list_entry_get_next',
-                          'udev_list_entry_get_name',
-                          'udev_list_entry_get_value']
+    functions_to_patch = [
+        function, 'udev_list_entry_get_next', 'udev_list_entry_get_name',
+        'udev_list_entry_get_value'
+    ]
     mocks = dict((f, mock.DEFAULT) for f in functions_to_patch)
     with mock.patch.multiple(libudev, **mocks):
         udev_list = LinkedList.from_iterable(items)
@@ -95,5 +94,6 @@ def libudev_list(libudev, function, items):
 EXPOSED_FUNCTIONS = [libudev_list]
 
 
-def pytest_namespace():
-    return dict((f.__name__, f) for f in EXPOSED_FUNCTIONS)
+def pytest_configure():
+    for f in EXPOSED_FUNCTIONS:
+        setattr(pytest, f.__name__, f)
