@@ -15,7 +15,6 @@
 # along with this library; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
-
 from __future__ import (print_function, division, unicode_literals,
                         absolute_import)
 
@@ -30,6 +29,7 @@ from tests._constants import _UDEV_TEST
 
 from tests.utils import is_unicode_string
 
+
 def test_udev_version():
     assert isinstance(udev_version(), int)
     # just to make sure, that udev versioning works.  pyudev itself should be
@@ -39,7 +39,6 @@ def test_udev_version():
 
 
 class TestContext(object):
-
     def test_sys_path(self, context):
         assert is_unicode_string(context.sys_path)
         assert context.sys_path == '/sys'
@@ -60,8 +59,8 @@ class TestContext(object):
     def test_log_priority_get_mock(self, context):
         spec = lambda c: None
         funcname = 'udev_get_log_priority'
-        with mock.patch.object(context._libudev, funcname,
-                               autospec=spec) as func:
+        with mock.patch.object(
+                context._libudev, funcname, autospec=spec) as func:
             func.return_value = mock.sentinel.log_priority
             assert context.log_priority is mock.sentinel.log_priority
             func.assert_called_once_with(context)
@@ -69,8 +68,8 @@ class TestContext(object):
     def test_log_priority_set_mock(self, context):
         spec = lambda c, p: None
         funcname = 'udev_set_log_priority'
-        with mock.patch.object(context._libudev, funcname,
-                               autospec=spec) as func:
+        with mock.patch.object(
+                context._libudev, funcname, autospec=spec) as func:
             context.log_priority = mock.sentinel.log_priority
             func.assert_called_once_with(context, mock.sentinel.log_priority)
 
@@ -79,7 +78,8 @@ class TestContext(object):
         old_priority = context.log_priority
         available_levels = [
             l for l in range(syslog.LOG_EMERG, syslog.LOG_DEBUG + 1)
-            if l != old_priority]
+            if l != old_priority
+        ]
         new_priority = random.choice(available_levels)
         assert new_priority != old_priority
         try:
