@@ -26,12 +26,12 @@ from pyudev import Monitor, Devices
 
 @pytest.fixture
 def monitor(request):
-    return Monitor.from_netlink(request.getfuncargvalue('context'))
+    return Monitor.from_netlink(request.getfixturevalue('context'))
 
 
 @pytest.fixture
 def fake_monitor_device(request):
-    context = request.getfuncargvalue('context')
+    context = request.getfixturevalue('context')
     return Devices.from_path(context, '/devices/platform')
 
 
@@ -39,7 +39,6 @@ ACTIONS = ('add', 'remove', 'change', 'move')
 
 
 class DeprecatedObserverTestBase(object):
-
     def setup_method(self, method):
         self.observer = None
         self.no_emitted_signals = 0
@@ -98,44 +97,14 @@ class DeprecatedObserverTestBase(object):
         self.connect_signal(action_callback, action=action)
         funcname = 'udev_device_get_action'
         spec = lambda d: None
-        with mock.patch.object(fake_monitor_device._libudev, funcname,
-                               autospec=spec) as func:
+        with mock.patch.object(
+                fake_monitor_device._libudev, funcname, autospec=spec) as func:
             func.return_value = action.encode('ascii')
             self.start_event_loop(fake_monitor.trigger_event)
             func.assert_called_with(fake_monitor_device)
         event_callback.assert_called_with(action, fake_monitor_device)
         action_callback.assert_called_with(fake_monitor_device)
 
-    @pytest.mark.privileged
-    def test_events_real(self, context, monitor):
-        # make sure that the module is unloaded initially
-        pytest.unload_dummy()
-        monitor.filter_by('net')
-        monitor.start()
-        self.prepare_test(monitor)
-        # setup signal handlers
-        event_callback = mock.Mock(side_effect=self.stop_when_done)
-        added_callback = mock.Mock(side_effect=self.stop_when_done)
-        removed_callback = mock.Mock(side_effect=self.stop_when_done)
-        self.connect_signal(event_callback)
-        self.connect_signal(added_callback, action='add')
-        self.connect_signal(removed_callback, action='remove')
-
-        # test add event
-        self.start_event_loop(pytest.load_dummy)
-        device = Devices.from_path(context, '/devices/virtual/net/dummy0')
-        event_callback.assert_called_with('add', device)
-        added_callback.assert_called_with(device)
-        assert not removed_callback.called
-
-        for callback in (event_callback, added_callback, removed_callback):
-            callback.reset_mock()
-
-        self.start_event_loop(pytest.unload_dummy)
-        event_callback.assert_called_with('remove', device)
-        assert not added_callback.called
-        removed_callback.assert_called_with(device)
-
 
 class DeprecatedQtObserverTestBase(DeprecatedObserverTestBase):
 
@@ -166,8 +135,7 @@ class DeprecatedQtObserverTestBase(DeprecatedObserverTestBase):
         self.app = self.qtcore.QCoreApplication.instance()
         if not self.app:
             self.app = self.qtcore.QCoreApplication([])
-        self.qtcore.QTimer.singleShot(
-            self_stop_timeout, self.stop_event_loop)
+        self.qtcore.QTimer.singleShot(self_stop_timeout, self.stop_event_loop)
 
     def start_event_loop(self, start_callback):
         self.qtcore.QTimer.singleShot(0, start_callback)
@@ -212,6 +180,7 @@ class TestDeprecatedGlibObserver(DeprecatedObserverTestBase):
         # drop the sender argument from glib signal connections
         def _wrapper(obj, *args, **kwargs):
             return callback(*args, **kwargs)
+
         if action is None:
             self.observer.connect('device-event', _wrapper)
         else:
@@ -226,6 +195,7 @@ class TestDeprecatedGlibObserver(DeprecatedObserverTestBase):
         def _wrapper(*args, **kwargs):
             start_callback(*args, **kwargs)
             return False
+
         self.event_sources.append(self.glib.timeout_add(0, _wrapper))
         self.mainloop.run()
 
@@ -234,10 +204,9 @@ class TestDeprecatedGlibObserver(DeprecatedObserverTestBase):
         return False
 
 
-@pytest.mark.skipif(str('"DISPLAY" not in os.environ'),
-                    reason='Display required for wxPython')
+@pytest.mark.skipif(
+    str('"DISPLAY" not in os.environ'), reason='Display required for wxPython')
 class TestDeprecatedWxObserver(DeprecatedObserverTestBase):
-
     def setup(self):
         self.wx = pytest.importorskip('wx')
 
@@ -245,21 +214,25 @@ class TestDeprecatedWxObserver(DeprecatedObserverTestBase):
         from pyudev import wx
         self.observer = wx.WxUDevMonitorObserver(monitor)
         self.action_event_map = {
-                'add': wx.EVT_DEVICE_ADDED,
-                'remove': wx.EVT_DEVICE_REMOVED,
-                'change': wx.EVT_DEVICE_CHANGED,
-                'move': wx.EVT_DEVICE_MOVED
+            'add': wx.EVT_DEVICE_ADDED,
+            'remove': wx.EVT_DEVICE_REMOVED,
+            'change': wx.EVT_DEVICE_CHANGED,
+            'move': wx.EVT_DEVICE_MOVED
         }
 
     def connect_signal(self, callback, action=None):
         if action is None:
             from pyudev.wx import EVT_DEVICE_EVENT
+
             def _wrapper(event):
                 return callback(event.action, event.device)
+
             self.observer.Bind(EVT_DEVICE_EVENT, _wrapper)
         else:
+
             def _wrapper(event):
                 return callback(event.device)
+
             self.observer.Bind(self.action_event_map[action], _wrapper)
 
     def create_event_loop(self, self_stop_timeout=5000):
